Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2114)

Unified Diff: ash/common/wm_shell.h

Issue 2237903003: mash: Migrate Shelf aura::Window uses to WmWindow. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Move shelf notify functions to WmShell. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/aura/wm_shelf_aura.cc ('k') | ash/common/wm_shell.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm_shell.h
diff --git a/ash/common/wm_shell.h b/ash/common/wm_shell.h
index 8dd3d7eb4d6e70841e7dfbfa540547e8ef80e2a1..d23dd459bc50484f3bcbcbb9f33179143435372d 100644
--- a/ash/common/wm_shell.h
+++ b/ash/common/wm_shell.h
@@ -283,16 +283,26 @@ class ASH_EXPORT WmShell {
// Called after overview mode has ended.
virtual void OnOverviewModeEnded() = 0;
// Notifies observers after toggling fullscreen mode in |root_window|.
void NotifyFullscreenStateChanged(bool is_fullscreen, WmWindow* root_window);
- // Notifies |observers_| when entering or exiting pinned mode for
- // |pinned_window|. Entering or exiting can be checked by looking at
- // |pinned_window|'s window state.
+ // Notify observers that |pinned_window| changed its pinned window state.
void NotifyPinnedStateChanged(WmWindow* pinned_window);
- // Called when virtual keyboard has been activated/deactivated.
- void OnVirtualKeyboardActivated(bool activated);
+ // Notify observers that the virtual keyboard has been activated/deactivated.
+ void NotifyVirtualKeyboardActivated(bool activated);
+
+ // Notify observers that the shelf was created for |root_window|.
+ // TODO(jamescook): Move to Shelf.
+ void NotifyShelfCreatedForRootWindow(WmWindow* root_window);
+
+ // Notify observers that |root_window|'s shelf changed auto-hide alignment.
+ // TODO(jamescook): Move to Shelf.
+ void NotifyShelfAlignmentChanged(WmWindow* root_window);
+
+ // Notify observers that |root_window|'s shelf changed auto-hide behavior.
+ // TODO(jamescook): Move to Shelf.
+ void NotifyShelfAutoHideBehaviorChanged(WmWindow* root_window);
virtual SessionStateDelegate* GetSessionStateDelegate() = 0;
« no previous file with comments | « ash/aura/wm_shelf_aura.cc ('k') | ash/common/wm_shell.cc » ('j') | no next file with comments »
@@ -283,16 +283,26 @@ class ASH_EXPORT WmShell {
// Called after overview mode has ended.
virtual void OnOverviewModeEnded() = 0;
- // Notifies observers after toggling fullscreen mode in |root_window|.
+ // Notify observers that fullscreen mode has changed for |root_window|.
void NotifyFullscreenStateChanged(bool is_fullscreen, WmWindow* root_window);

Powered by Google App Engine
This is Rietveld 408576698